#define UTS_MACHINE		"arm"
#define LINUX_COMPILE_BY	"oe-user"
#define LINUX_COMPILE_HOST	"oe-host"
#define LINUX_COMPILER		"arm-amd-linux-gnueabi-gcc (GCC) 13.4.0, GNU ld (GNU Binutils) 2.42.0.20240723"
