/* SPDX-License-Identifier: GPL-2.0 */
/*
 *  arch/arm/mach-footbridge/include/mach/isa-dma.h
 *
 *  Architecture DMA routines
 *
 *  Copyright (C) 1998,1999 Russell King
 *  Copyright (C) 1998,1999 Philip Blundell
 */
#ifndef __ASM_ARCH_DMA_H
#define __ASM_ARCH_DMA_H

#define MAX_DMA_CHANNELS	8

#define DMA_FLOPPY		(2)
#define DMA_ISA_CASCADE		(4)

#endif /* _ASM_ARCH_DMA_H */
