/*
 * Automatically generated file; DO NOT EDIT.
 * Linux/arm 6.12.40 Kernel Configuration
 */
#define CONFIG_USB_COMMON 1
#define CONFIG_MTD_MAP_BANK_WIDTH_1 1
#define CONFIG_MMC 1
#define CONFIG_GPIOLIB 1
#define CONFIG_DVB_LGS8GXX_MODULE 1
#define CONFIG_NFS_V3 1
#define CONFIG_VIDEO_DEV 1
#define CONFIG_NET_VENDOR_MICROSEMI 1
#define CONFIG_NET_VENDOR_NI 1
#define CONFIG_USB_ROLE_SWITCH 1
#define CONFIG_NET_HANDSHAKE 1
#define CONFIG_LIBFDT 1
#define CONFIG_R8169 1
#define CONFIG_PAGE_SHIFT 12
#define CONFIG_NLS_ASCII 1
#define CONFIG_UEVENT_HELPER 1
#define CONFIG_NFS_COMMON 1
#define CONFIG_DVB_ISL6423_MODULE 1
#define CONFIG_I2C_CADENCE 1
#define CONFIG_IKCONFIG 1
#define CONFIG_TREE_RCU 1
#define CONFIG_GENERIC_SCHED_CLOCK 1
#define CONFIG_ARM_V7_PMU 1
#define CONFIG_NLS_CODEPAGE_437 1
#define CONFIG_ARCH_USE_BUILTIN_BSWAP 1
#define CONFIG_SBITMAP 1
#define CONFIG_DMA_NONCOHERENT_MMAP 1
#define CONFIG_AS_IS_GNU 1
#define CONFIG_ARCH_HAS_BINFMT_FLAT 1
#define CONFIG_STACKPROTECTOR_STRONG 1
#define CONFIG_IIO_TRIGGER 1
#define CONFIG_V4L2_FWNODE 1
#define CONFIG_INIT_STACK_ALL_ZERO 1
#define CONFIG_MMC_SDHCI_OF_ARASAN 1
#define CONFIG_RANDSTRUCT_NONE 1
#define CONFIG_RTC_I2C_AND_SPI 1
#define CONFIG_CMA_SIZE_SEL_MBYTES 1
#define CONFIG_TMPFS 1
#define CONFIG_PMBUS 1
#define CONFIG_DVB_LGS8GL5_MODULE 1
#define CONFIG_BIG_LITTLE 1
#define CONFIG_IPV6 1
#define CONFIG_SCSI_DMA 1
#define CONFIG_SIGNALFD 1
#define CONFIG_CPU_FREQ_GOV_PERFORMANCE 1
#define CONFIG_MTD_MAP_BANK_WIDTH_2 1
#define CONFIG_NET_VENDOR_ASIX 1
#define CONFIG_SYSFS_SYSCALL 1
#define CONFIG_HAVE_UID16 1
#define CONFIG_NET_IPIP_MODULE 1
#define CONFIG_AIO 1
#define CONFIG_GENERIC_IRQ_SHOW 1
#define CONFIG_ARM_THUMB 1
#define CONFIG_BLOCK_LEGACY_AUTOLOAD 1
#define CONFIG_XILINX_WATCHDOG 1
#define CONFIG_MTD_RAW_NAND 1
#define CONFIG_RPCSEC_GSS_KRB5 1
#define CONFIG_BOUNCE 1
#define CONFIG_CPU_CACHE_V7 1
#define CONFIG_GENERIC_STRNLEN_USER 1
#define CONFIG_OF_IRQ 1
#define CONFIG_HIGHMEM 1
#define CONFIG_PGTABLE_LEVELS 2
#define CONFIG_CRYPTO_ECB 1
#define CONFIG_NET_VENDOR_MICROSOFT 1
#define CONFIG_REGMAP 1
#define CONFIG_DVB_ZL10039_MODULE 1
#define CONFIG_GENERIC_HWEIGHT 1
#define CONFIG_ARCH_WANT_IPC_PARSE_VERSION 1
#define CONFIG_ARCH_HAS_MEMBARRIER_SYNC_CORE 1
#define CONFIG_HAVE_C_RECORDMCOUNT 1
#define CONFIG_MAC80211_STA_HASH_MAX_SIZE 0
#define CONFIG_TICK_ONESHOT 1
#define CONFIG_DRM 1
#define CONFIG_HAVE_KERNEL_LZMA 1
#define CONFIG_ARCH_MULTIPLATFORM 1
#define CONFIG_BCMA_POSSIBLE 1
#define CONFIG_NET_VENDOR_VERTEXCOM 1
#define CONFIG_CPU_LITTLE_ENDIAN 1
#define CONFIG_NET_VENDOR_DAVICOM 1
#define CONFIG_ARM_GLOBAL_TIMER 1
#define CONFIG_EVENTFD 1
#define CONFIG_GENERIC_CPU_VULNERABILITIES 1
#define CONFIG_MTD_NAND_PL35X 1
#define CONFIG_SND_SOC_I2C_AND_SPI 1
#define CONFIG_ARCH_WANT_FLAT_DTB_INSTALL 1
#define CONFIG_ZLIB_DEFLATE 1
#define CONFIG_HAVE_PROC_CPU 1
#define CONFIG_NET_VENDOR_CHELSIO 1
#define CONFIG_FILE_LOCKING 1
#define CONFIG_DVB_LNBH29_MODULE 1
#define CONFIG_REGULATOR_FIXED_VOLTAGE 1
#define CONFIG_SND_HDA_PREALLOC_SIZE 64
#define CONFIG_PAGE_SIZE_4KB 1
#define CONFIG_CPU_THUMB_CAPABLE 1
#define CONFIG_I2C_CHARDEV 1
#define CONFIG_AF_UNIX_OOB 1
#define CONFIG_DVB_MN88472_MODULE 1
#define CONFIG_HAVE_DYNAMIC_FTRACE 1
#define CONFIG_ARCH_SUPPORTS_CRASH_DUMP 1
#define CONFIG_DVB_OR51211_MODULE 1
#define CONFIG_NET_VENDOR_SUN 1
#define CONFIG_ARM_ERRATA_775420 1
#define CONFIG_ARCH_MULTI_V7 1
#define CONFIG_GENERIC_MSI_IRQ 1
#define CONFIG_OF_DYNAMIC 1
#define CONFIG_POWER_SUPPLY 1
#define CONFIG_HAVE_MOD_ARCH_SPECIFIC 1
#define CONFIG_WLAN_VENDOR_ATMEL 1
#define CONFIG_DEVTMPFS 1
#define CONFIG_HAVE_DEBUG_KMEMLEAK 1
#define CONFIG_NET_VENDOR_CORTINA 1
#define CONFIG_INPUT_EVDEV 1
#define CONFIG_NETWORK_FILESYSTEMS 1
#define CONFIG_CROSS_MEMORY_ATTACH 1
#define CONFIG_LD_ORPHAN_WARN 1
#define CONFIG_INET_TCP_DIAG 1
#define CONFIG_KEYBOARD_ATKBD 1
#define CONFIG_ARCH_WANT_LD_ORPHAN_WARN 1
#define CONFIG_CPU_CP15_MMU 1
#define CONFIG_VIDEO 1
#define CONFIG_GENERIC_EARLY_IOREMAP 1
#define CONFIG_OF_FLATTREE 1
#define CONFIG_DVB_MN88473_MODULE 1
#define CONFIG_INPUT_FF_MEMLESS 1
#define CONFIG_XZ_DEC_SPARC 1
#define CONFIG_CC_HAS_NO_PROFILE_FN_ATTR 1
#define CONFIG_ARM_HAS_GROUP_RELOCS 1
#define CONFIG_OF_GPIO 1
#define CONFIG_VEXPRESS_CONFIG 1
#define CONFIG_DVB_MB86A20S_MODULE 1
#define CONFIG_RCU_CPU_STALL_TIMEOUT 60
#define CONFIG_RCU_TRACE 1
#define CONFIG_USB_EHCI_HCD 1
#define CONFIG_XILINX_EMACLITE 1
#define CONFIG_STRICT_KERNEL_RWX 1
#define CONFIG_SWP_EMULATE 1
#define CONFIG_MEDIA_TUNER_MT2266_MODULE 1
#define CONFIG_HID_SUPPORT 1
#define CONFIG_MACB 1
#define CONFIG_VFAT_FS 1
#define CONFIG_NET_VENDOR_ROCKER 1
#define CONFIG_LEDS_GPIO 1
#define CONFIG_WLAN_VENDOR_ADMTEK 1
#define CONFIG_PACKET 1
#define CONFIG_LEDS_TRIGGER_TRANSIENT 1
#define CONFIG_VGA_ARB_MAX_GPUS 16
#define CONFIG_NO_HZ_COMMON 1
#define CONFIG_STACKDEPOT_MAX_FRAMES 64
#define CONFIG_ZSTD_DECOMPRESS 1
#define CONFIG_FAT_FS 1
#define CONFIG_PCI_DOMAINS_GENERIC 1
#define CONFIG_ARCH_SUPPORTS_PER_VMA_LOCK 1
#define CONFIG_NR_CPUS 4
#define CONFIG_ARCH_HIBERNATION_POSSIBLE 1
#define CONFIG_HAVE_FUNCTION_TRACER 1
#define CONFIG_LOG_BUF_SHIFT 14
#define CONFIG_LEDS_TRIGGER_DEFAULT_ON 1
#define CONFIG_DVB_DRX39XYJ_MODULE 1
#define CONFIG_CAN_DEV 1
#define CONFIG_MDIO_DEVICE 1
#define CONFIG_KRETPROBES 1
#define CONFIG_HAVE_ARM_SCU 1
#define CONFIG_LOCKD 1
#define CONFIG_RPMSG_CTRL_MODULE 1
#define CONFIG_KMAP_LOCAL 1
#define CONFIG_COMPAT_BRK 1
#define CONFIG_VIDEOBUF2_VMALLOC_MODULE 1
#define CONFIG_INPUT 1
#define CONFIG_WLAN_VENDOR_RSI 1
#define CONFIG_GENERIC_IRQ_IPI 1
#define CONFIG_BLK_MQ_VIRTIO 1
#define CONFIG_OF_FPGA_REGION 1
#define CONFIG_PWRSEQ_EMMC 1
#define CONFIG_RADIO_ADAPTERS 1
#define CONFIG_FPGA_BRIDGE 1
#define CONFIG_DEV_COREDUMP 1
#define CONFIG_SLAB_MERGE_DEFAULT 1
#define CONFIG_CPU_TLB_V7 1
#define CONFIG_OF_EARLY_FLATTREE 1
#define CONFIG_BLK_ICQ 1
#define CONFIG_HAVE_GCC_PLUGINS 1
#define CONFIG_DVB_AF9033_MODULE 1
#define CONFIG_NO_HZ 1
#define CONFIG_CLK_VEXPRESS_OSC 1
#define CONFIG_I2C_MUX_PCA954x 1
#define CONFIG_ARM_L1_CACHE_SHIFT_6 1
#define CONFIG_LLC_MODULE 1
#define CONFIG_MFD_SYSCON 1
#define CONFIG_GPIOLIB_FASTPATH_LIMIT 512
#define CONFIG_GENERIC_IRQ_SHOW_LEVEL 1
#define CONFIG_RESET_CONTROLLER 1
#define CONFIG_HARDIRQS_SW_RESEND 1
#define CONFIG_IIO_CONSUMERS_PER_TRIGGER 2
#define CONFIG_ARCH_HAVE_NMI_SAFE_CMPXCHG 1
#define CONFIG_ARCH_OPTIONAL_KERNEL_RWX_DEFAULT 1
#define CONFIG_FREEZER 1
#define CONFIG_VM_EVENT_COUNTERS 1
#define CONFIG_PAGE_SIZE_LESS_THAN_64KB 1
#define CONFIG_VLAN_8021Q_MODULE 1
#define CONFIG_ARM_GIC_MAX_NR 1
#define CONFIG_BLK_DEV 1
#define CONFIG_HARDEN_BRANCH_HISTORY 1
#define CONFIG_CAN_GW 1
#define CONFIG_NET_RX_BUSY_POLL 1
#define CONFIG_EDAC 1
#define CONFIG_USB_CHIPIDEA_HOST 1
#define CONFIG_PAHOLE_VERSION 0
#define CONFIG_MEDIA_SUPPORT 1
#define CONFIG_MOUSE_PS2_LOGIPS2PP 1
#define CONFIG_ARM_GT_INITIAL_PRESCALER_VAL 2
#define CONFIG_TRACE_CLOCK 1
#define CONFIG_RTC_INTF_SYSFS 1
#define CONFIG_MOUSE_PS2_FOCALTECH 1
#define CONFIG_DVB_L64781_MODULE 1
#define CONFIG_TASKS_RCU_GENERIC 1
#define CONFIG_CONTEXT_TRACKING 1
#define CONFIG_DVB_LGDT3305_MODULE 1
#define CONFIG_WLAN 1
#define CONFIG_MOUSE_PS2_SYNAPTICS_SMBUS 1
#define CONFIG_DRM_PANEL_ORIENTATION_QUIRKS 1
#define CONFIG_MTD_GEN_PROBE 1
#define CONFIG_WLAN_VENDOR_INTERSIL 1
#define CONFIG_ARCH_HAS_TICK_BROADCAST 1
#define CONFIG_DVB_SP2_MODULE 1
#define CONFIG_PWRSEQ_SIMPLE 1
#define CONFIG_DVB_AU8522_MODULE 1
#define CONFIG_DVB_CXD2820R_MODULE 1
#define CONFIG_DEFAULT_MMAP_MIN_ADDR 4096
#define CONFIG_WLAN_VENDOR_BROADCOM 1
#define CONFIG_DVB_TUNER_ITD1000_MODULE 1
#define CONFIG_DVB_NXT6000_MODULE 1
#define CONFIG_KCMP 1
#define CONFIG_BUILD_SALT ""
#define CONFIG_DUMMY_CONSOLE_ROWS 30
#define CONFIG_IP_PNP_BOOTP 1
#define CONFIG_MODPROBE_PATH "/sbin/modprobe"
#define CONFIG_MQ_IOSCHED_DEADLINE 1
#define CONFIG_HAVE_CLK 1
#define CONFIG_MEDIA_CEC_SUPPORT 1
#define CONFIG_FUTEX 1
#define CONFIG_ARCH_HAS_CURRENT_STACK_POINTER 1
#define CONFIG_HAVE_FUNCTION_ERROR_INJECTION 1
#define CONFIG_XILINX_XADC 1
#define CONFIG_HAS_DMA 1
#define CONFIG_SOFTIRQ_ON_OWN_STACK 1
#define CONFIG_STACKDEPOT 1
#define CONFIG_RESET_ZYNQ 1
#define CONFIG_CPU_FREQ_GOV_COMMON 1
#define CONFIG_LEGACY_DIRECT_IO 1
#define CONFIG_LOCK_SPIN_ON_OWNER 1
#define CONFIG_HAVE_PERF_USER_STACK_DUMP 1
#define CONFIG_OPTPROBES 1
#define CONFIG_SERIAL_CORE 1
#define CONFIG_DVB_DIB9000_MODULE 1
#define CONFIG_LEDS_TRIGGERS 1
#define CONFIG_SND_USB 1
#define CONFIG_GPIO_CDEV_V1 1
#define CONFIG_SYN_COOKIES 1
#define CONFIG_ARCH_HAS_FORTIFY_SOURCE 1
#define CONFIG_NET_VENDOR_QUALCOMM 1
#define CONFIG_STACKTRACE_SUPPORT 1
#define CONFIG_USB_GADGET_XILINX 1
#define CONFIG_PCIEASPM_DEFAULT 1
#define CONFIG_FPGA 1
#define CONFIG_SND 1
#define CONFIG_SECTION_MISMATCH_WARN_ONLY 1
#define CONFIG_CC_IS_GCC 1
#define CONFIG_CMDLINE ""
#define CONFIG_INITRAMFS_PRESERVE_MTIME 1
#define CONFIG_DMA_ENGINE 1
#define CONFIG_FPGA_REGION 1
#define CONFIG_DVB_TDA10048_MODULE 1
#define CONFIG_ARCH_SELECT_MEMORY_MODEL 1
#define CONFIG_CRYPTO_CRC32C 1
#define CONFIG_DVB_S5H1432_MODULE 1
#define CONFIG_RD_BZIP2 1
#define CONFIG_MEDIA_TUNER_MAX2165_MODULE 1
#define CONFIG_DVB_LNBP22_MODULE 1
#define CONFIG_HAVE_FUNCTION_GRAPH_TRACER 1
#define CONFIG_LOCK_DEBUGGING_SUPPORT 1
#define CONFIG_VIDEOBUF2_DMA_CONTIG 1
#define CONFIG_JFFS2_RTIME 1
#define CONFIG_DVB_AU8522_V4L_MODULE 1
#define CONFIG_MEMORY 1
#define CONFIG_ZBOOT_ROM_BSS 0x0
#define CONFIG_NET_VENDOR_SYNOPSYS 1
#define CONFIG_ARCH_HAS_GCOV_PROFILE_ALL 1
#define CONFIG_XZ_DEC_BCJ 1
#define CONFIG_MTD_CMDLINE_PARTS 1
#define CONFIG_DRM_KMS_HELPER 1
#define CONFIG_PL310_ERRATA_753970 1
#define CONFIG_MOUSE_PS2_BYD 1
#define CONFIG_MOUSE_PS2_TRACKPOINT 1
#define CONFIG_SCHED_HRTICK 1
#define CONFIG_TRACING_SUPPORT 1
#define CONFIG_HAVE_ARM_TWD 1
#define CONFIG_USB_F_SS_LB_MODULE 1
#define CONFIG_USB_EHCI_PCI 1
#define CONFIG_VIRTIO_MENU 1
#define CONFIG_NET_VENDOR_CADENCE 1
#define CONFIG_SPLIT_PTE_PTLOCKS 1
#define CONFIG_BLK_DEV_WRITE_MOUNTED 1
#define CONFIG_NET_VENDOR_BROCADE 1
#define CONFIG_CC_NO_STRINGOP_OVERFLOW 1
#define CONFIG_LEDS_TRIGGER_TIMER 1
#define CONFIG_NET_SELFTESTS 1
#define CONFIG_AS_HAS_NON_CONST_ULEB128 1
#define CONFIG_LLD_VERSION 0
#define CONFIG_REMOTEPROC 1
#define CONFIG_CRYPTO_HASH 1
#define CONFIG_MEDIA_ATTACH 1
#define CONFIG_GPIOLIB_IRQCHIP 1
#define CONFIG_SUNRPC 1
#define CONFIG_THERMAL_EMERGENCY_POWEROFF_DELAY_MS 0
#define CONFIG_DVB_STV0900_MODULE 1
#define CONFIG_GENERIC_CPU_DEVICES 1
#define CONFIG_CONNECTOR 1
#define CONFIG_CPU_IDLE 1
#define CONFIG_MTD_CFI 1
#define CONFIG_PREEMPT_COUNT 1
#define CONFIG_CAN 1
#define CONFIG_KUSER_HELPERS 1
#define CONFIG_DVB_NXT200X_MODULE 1
#define CONFIG_ARCH_HAS_CPU_CACHE_ALIASING 1
#define CONFIG_PM_CLK 1
#define CONFIG_ARM_ERRATA_764369 1
#define CONFIG_SND_PCM_TIMER 1
#define CONFIG_SCSI_PROC_FS 1
#define CONFIG_DVB_STB6000_MODULE 1
#define CONFIG_CRYPTO_HW 1
#define CONFIG_ARM_ERRATA_720789 1
#define CONFIG_USB_F_MASS_STORAGE_MODULE 1
#define CONFIG_COREDUMP 1
#define CONFIG_CC_HAS_ZERO_CALL_USED_REGS 1
#define CONFIG_ARCH_KEEP_MEMBLOCK 1
#define CONFIG_CRYPTO_HASH2 1
#define CONFIG_SECCOMP 1
#define CONFIG_HID_MICROSOFT 1
#define CONFIG_SHMEM 1
#define CONFIG_DVB_MN88443X_MODULE 1
#define CONFIG_DVB_DIB3000MC_MODULE 1
#define CONFIG_I2C_BOARDINFO 1
#define CONFIG_UIO 1
#define CONFIG_NET_VENDOR_ALTEON 1
#define CONFIG_VIRTIO_ANCHOR 1
#define CONFIG_SND_TIMER 1
#define CONFIG_ARCH_VEXPRESS_CORTEX_A5_A9_ERRATA 1
#define CONFIG_BRIDGE_MODULE 1
#define CONFIG_IRQ_FORCED_THREADING 1
#define CONFIG_CRYPTO_MANAGER2 1
#define CONFIG_MESSAGE_LOGLEVEL_DEFAULT 4
#define CONFIG_WLAN_VENDOR_ATH 1
#define CONFIG_DVB_S921_MODULE 1
#define CONFIG_WLAN_VENDOR_MARVELL 1
#define CONFIG_SOCK_RX_QUEUE_MAPPING 1
#define CONFIG_KMAP_LOCAL_NON_LINEAR_PTE_ARRAY 1
#define CONFIG_SERIAL_XILINX_PS_UART_CONSOLE 1
#define CONFIG_VIDEO_XILINX_VTC 1
#define CONFIG_DECOMPRESS_LZ4 1
#define CONFIG_DVB_CX24117_MODULE 1
#define CONFIG_NLS_ISO8859_1 1
#define CONFIG_ARCH_HAS_KCOV 1
#define CONFIG_NET_VENDOR_CAVIUM 1
#define CONFIG_WLAN_VENDOR_ZYDAS 1
#define CONFIG_CPU_ABRT_EV7 1
#define CONFIG_DTC 1
#define CONFIG_CRYPTO_LIB_POLY1305_RSIZE 9
#define CONFIG_INIT_ENV_ARG_LIMIT 32
#define CONFIG_VIDEO_XILINX 1
#define CONFIG_STANDALONE 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_ZERO 1
#define CONFIG_DVB_DRXK_MODULE 1
#define CONFIG_I2C_HID 1
#define CONFIG_PREEMPT_BUILD 1
#define CONFIG_ARCH_MULTI_V6_V7 1
#define CONFIG_DEFAULT_TCP_CONG "cubic"
#define CONFIG_ARM_HEAVY_MB 1
#define CONFIG_MTD_CFI_UTIL 1
#define CONFIG_WLAN_VENDOR_SILABS 1
#define CONFIG_NET_VENDOR_OKI 1
#define CONFIG_SPI_MEM 1
#define CONFIG_MMC_BLOCK 1
#define CONFIG_GCC_NO_STRINGOP_OVERFLOW 1
#define CONFIG_CONTIG_ALLOC 1
#define CONFIG_ARM 1
#define CONFIG_CPU_FREQ_GOV_ATTR_SET 1
#define CONFIG_RWSEM_SPIN_ON_OWNER 1
#define CONFIG_ARCH_HAS_STRICT_MODULE_RWX 1
#define CONFIG_DVB_DIB3000MB_MODULE 1
#define CONFIG_DVB_TS2020_MODULE 1
#define CONFIG_CACHE_L2X0 1
#define CONFIG_WLAN_VENDOR_INTEL 1
#define CONFIG_HAVE_IRQ_EXIT_ON_IRQ_STACK 1
#define CONFIG_GPIO_GENERIC_PLATFORM 1
#define CONFIG_DVB_LNBP21_MODULE 1
#define CONFIG_HOTPLUG_CORE_SYNC 1
#define CONFIG_DVB_AU8522_DTV_MODULE 1
#define CONFIG_NET_VENDOR_ATHEROS 1
#define CONFIG_DVB_SP887X_MODULE 1
#define CONFIG_LEDS_TRIGGER_CAMERA 1
#define CONFIG_DVB_TDA10021_MODULE 1
#define CONFIG_ELFCORE 1
#define CONFIG_BLK_PM 1
#define CONFIG_DVB_CX24116_MODULE 1
#define CONFIG_NET_VENDOR_SILAN 1
#define CONFIG_MEDIA_TUNER_MXL5005S_MODULE 1
#define CONFIG_SENSORS_UCD9000 1
#define CONFIG_MCPM 1
#define CONFIG_SND_VERBOSE_PROCFS 1
#define CONFIG_MEDIA_TUNER_TDA827X_MODULE 1
#define CONFIG_GENERIC_CPU_AUTOPROBE 1
#define CONFIG_WLAN_VENDOR_ST 1
#define CONFIG_JFFS2_ZLIB 1
#define CONFIG_NETDEVICES 1
#define CONFIG_PL310_ERRATA_588369 1
#define CONFIG_SPI_XILINX 1
#define CONFIG_ETHTOOL_NETLINK 1
#define CONFIG_COMMON_CLK 1
#define CONFIG_HAVE_ARM_SMCCC 1
#define CONFIG_PHYLINK 1
#define CONFIG_DMA_SHARED_BUFFER 1
#define CONFIG_MODULES 1
#define CONFIG_SCHED_HW_PRESSURE 1
#define CONFIG_CACHESTAT_SYSCALL 1
#define CONFIG_CMA_SIZE_MBYTES 16
#define CONFIG_NFS_DISABLE_UDP_SUPPORT 1
#define CONFIG_MAX_SKB_FRAGS 17
#define CONFIG_CRYPTO_ACOMP2 1
#define CONFIG_BINFMT_FLAT_ARGVP_ENVP_ON_STACK 1
#define CONFIG_INET_TABLE_PERTURB_ORDER 16
#define CONFIG_IIO_BUFFER 1
#define CONFIG_NET_VENDOR_I825XX 1
#define CONFIG_BITREVERSE 1
#define CONFIG_HAVE_ARCH_KASAN_VMALLOC 1
#define CONFIG_IPV6_NDISC_NODETYPE 1
#define CONFIG_NET_VENDOR_PACKET_ENGINES 1
#define CONFIG_BLK_DEV_SD 1
#define CONFIG_USB_CHIPIDEA 1
#define CONFIG_ARCH_32BIT_OFF_T 1
#define CONFIG_HAVE_KPROBES 1
#define CONFIG_ARM_PAN 1
#define CONFIG_FLATMEM_MANUAL 1
#define CONFIG_MEDIA_PLATFORM_DRIVERS 1
#define CONFIG_MEDIA_TEST_SUPPORT 1
#define CONFIG_DVB_MB86A16_MODULE 1
#define CONFIG_CMA_ALIGNMENT 8
#define CONFIG_CAN_XILINXCAN 1
#define CONFIG_SYSVIPC_SYSCTL 1
#define CONFIG_I2C_MUX 1
#define CONFIG_DRM_PANEL 1
#define CONFIG_ARM_PATCH_IDIV 1
#define CONFIG_DMADEVICES 1
#define CONFIG_FS_MBCACHE 1
#define CONFIG_COMMON_CLK_SI570 1
#define CONFIG_TIMER_OF 1
#define CONFIG_PLAT_VERSATILE 1
#define CONFIG_NET_IP_TUNNEL 1
#define CONFIG_HAVE_PCI 1
#define CONFIG_DVB_TDA665x_MODULE 1
#define CONFIG_MEDIA_TUNER_QM1D1C0042_MODULE 1
#define CONFIG_DVB_TDA10023_MODULE 1
#define CONFIG_CHR_DEV_SG 1
#define CONFIG_MMU 1
#define CONFIG_MEDIA_TUNER_MT2131_MODULE 1
#define CONFIG_CRYPTO_RNG2 1
#define CONFIG_KEYBOARD_GPIO 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_WITH_REGS 1
#define CONFIG_WLAN_VENDOR_MEDIATEK 1
#define CONFIG_CAN_CALC_BITTIMING 1
#define CONFIG_HZ_100 1
#define CONFIG_ARCH_HAS_DEBUG_VIRTUAL 1
#define CONFIG_IOMMU_SUPPORT 1
#define CONFIG_ARCH_HAS_RESET_CONTROLLER 1
#define CONFIG_USB_CHIPIDEA_MSM 1
#define CONFIG_IP_PNP 1
#define CONFIG_OUTER_CACHE 1
#define CONFIG_PERF_USE_VMALLOC 1
#define CONFIG_MEMBARRIER 1
#define CONFIG_CPU_IDLE_GOV_MENU 1
#define CONFIG_JFFS2_FS_DEBUG 0
#define CONFIG_OF_ADDRESS 1
#define CONFIG_MEDIA_DIGITAL_TV_SUPPORT 1
#define CONFIG_NET_VENDOR_NETRONOME 1
#define CONFIG_DVB_LNBH25_MODULE 1
#define CONFIG_XZ_DEC 1
#define CONFIG_THERMAL_HWMON 1
#define CONFIG_LEDS_TRIGGER_CPU 1
#define CONFIG_HAVE_KERNEL_LZ4 1
#define CONFIG_PCI_QUIRKS 1
#define CONFIG_NET_VENDOR_FUNGIBLE 1
#define CONFIG_GENERIC_PINCONF 1
#define CONFIG_MOUSE_PS2 1
#define CONFIG_MEDIA_TUNER_SI2157_MODULE 1
#define CONFIG_PCPU_DEV_REFCNT 1
#define CONFIG_EDAC_ATOMIC_SCRUB 1
#define CONFIG_NET_VENDOR_AMAZON 1
#define CONFIG_MODULE_UNLOAD 1
#define CONFIG_NET_VENDOR_INTEL 1
#define CONFIG_THERMAL_DEFAULT_GOV_STEP_WISE 1
#define CONFIG_DVB_TDA8261_MODULE 1
#define CONFIG_CONSOLE_LOGLEVEL_DEFAULT 7
#define CONFIG_CADENCE_WATCHDOG 1
#define CONFIG_DVB_DIB7000M_MODULE 1
#define CONFIG_VITESSE_PHY 1
#define CONFIG_CONSOLE_TRANSLATIONS 1
#define CONFIG_CPU_FREQ_GOV_POWERSAVE 1
#define CONFIG_DVB_CX22700_MODULE 1
#define CONFIG_WATCHDOG_OPEN_TIMEOUT 0
#define CONFIG_BUILDTIME_TABLE_SORT 1
#define CONFIG_E1000E 1
#define CONFIG_HAVE_CONTEXT_TRACKING_USER 1
#define CONFIG_BINFMT_SCRIPT 1
#define CONFIG_PINMUX 1
#define CONFIG_CRYPTO_SIG2 1
#define CONFIG_VFPv3 1
#define CONFIG_DVB_STV0910_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA18271_MODULE 1
#define CONFIG_MULTIUSER 1
#define CONFIG_PCIE_XILINX 1
#define CONFIG_BRIDGE_IGMP_SNOOPING 1
#define CONFIG_CMA 1
#define CONFIG_ARCH_FORCE_MAX_ORDER 10
#define CONFIG_DVB_BCM3510_MODULE 1
#define CONFIG_BLOCK 1
#define CONFIG_PTP_1588_CLOCK_OPTIONAL 1
#define CONFIG_DEBUG_MISC 1
#define CONFIG_NET_VENDOR_3COM 1
#define CONFIG_CPU_FREQ 1
#define CONFIG_ARCH_HAS_TEARDOWN_DMA_OPS 1
#define CONFIG_FAT_DEFAULT_IOCHARSET "iso8859-1"
#define CONFIG_TTY 1
#define CONFIG_CPU_HAS_ASID 1
#define CONFIG_DECOMPRESS_LZMA 1
#define CONFIG_MOUSE_PS2_CYPRESS 1
#define CONFIG_SYMBOLIC_ERRNAME 1
#define CONFIG_LOCK_MM_AND_FIND_VMA 1
#define CONFIG_SOC_BUS 1
#define CONFIG_ARCH_USE_CMPXCHG_LOCKREF 1
#define CONFIG_ARCH_HAS_KEEPINITRD 1
#define CONFIG_CLK_SP810 1
#define CONFIG_AEABI 1
#define CONFIG_MEDIA_TUNER_TDA9887_MODULE 1
#define CONFIG_HAVE_KERNEL_XZ 1
#define CONFIG_CRYPTO_ALGAPI2 1
#define CONFIG_DMA_CMA 1
#define CONFIG_CPU_MITIGATIONS 1
#define CONFIG_MEDIA_TUNER_R820T_MODULE 1
#define CONFIG_XILINX_FRMBUF 1
#define CONFIG_PROC_MEM_ALWAYS_FORCE 1
#define CONFIG_PINCONF 1
#define CONFIG_FUNCTION_ALIGNMENT 0
#define CONFIG_DVB_TC90522_MODULE 1
#define CONFIG_LEDS_TRIGGER_HEARTBEAT 1
#define CONFIG_UNWINDER_ARM 1
#define CONFIG_PPS 1
#define CONFIG_GLOB 1
#define CONFIG_CAN_BCM 1
#define CONFIG_RPMSG_MODULE 1
#define CONFIG_SERIAL_XILINX_PS_UART 1
#define CONFIG_DEVMEM 1
#define CONFIG_USB_GADGET_VBUS_DRAW 2
#define CONFIG_MEDIA_TUNER_TDA18218_MODULE 1
#define CONFIG_DVB_DRXD_MODULE 1
#define CONFIG_LSM "landlock,lockdown,yama,loadpin,safesetid,ipe,bpf"
#define CONFIG_CRYPTO_ALGAPI 1
#define CONFIG_CLONE_BACKWARDS 1
#define CONFIG_CPU_COPY_V6 1
#define CONFIG_SERIAL_EARLYCON 1
#define CONFIG_DEVPORT 1
#define CONFIG_USB 1
#define CONFIG_ARCH_VEXPRESS 1
#define CONFIG_HARDEN_BRANCH_PREDICTOR 1
#define CONFIG_ELF_CORE 1
#define CONFIG_DVB_ATBM8830_MODULE 1
#define CONFIG_DVB_PLL_MODULE 1
#define CONFIG_THERMAL 1
#define CONFIG_SELECT_MEMORY_MODEL 1
#define CONFIG_DVB_LG2160_MODULE 1
#define CONFIG_NET_VENDOR_DLINK 1
#define CONFIG_TICK_CPU_ACCOUNTING 1
#define CONFIG_SND_DRIVERS 1
#define CONFIG_NET_VENDOR_EZCHIP 1
#define CONFIG_XZ_DEC_X86 1
#define CONFIG_VT_CONSOLE_SLEEP 1
#define CONFIG_NET_VENDOR_SOCIONEXT 1
#define CONFIG_RUSTC_VERSION 0
#define CONFIG_MTD_BLKDEVS 1
#define CONFIG_KERNEL_GZIP 1
#define CONFIG_DEBUG_KERNEL 1
#define CONFIG_WLAN_VENDOR_TI 1
#define CONFIG_IP_PNP_DHCP 1
#define CONFIG_VIDEOBUF2_CORE 1
#define CONFIG_MISC_FILESYSTEMS 1
#define CONFIG_MDIO_BITBANG 1
#define CONFIG_ARCH_ZYNQ 1
#define CONFIG_ARCH_OPTIONAL_KERNEL_RWX 1
#define CONFIG_INOTIFY_USER 1
#define CONFIG_DVB_CX22702_MODULE 1
#define CONFIG_PHYLIB 1
#define CONFIG_HDMI 1
#define CONFIG_HZ_FIXED 0
#define CONFIG_V4L_PLATFORM_DRIVERS 1
#define CONFIG_XILINX_DMA 1
#define CONFIG_WLAN_VENDOR_QUANTENNA 1
#define CONFIG_FAT_DEFAULT_CODEPAGE 437
#define CONFIG_NLATTR 1
#define CONFIG_DVB_SI21XX_MODULE 1
#define CONFIG_UNCOMPRESS_INCLUDE "debug/uncompress.h"
#define CONFIG_SCHED_MC 1
#define CONFIG_HAVE_EBPF_JIT 1
#define CONFIG_NET_VENDOR_ADAPTEC 1
#define CONFIG_NET_VENDOR_WANGXUN 1
#define CONFIG_RFS_ACCEL 1
#define CONFIG_HAVE_LD_DEAD_CODE_DATA_ELIMINATION 1
#define CONFIG_KALLSYMS 1
#define CONFIG_MDIO_BUS 1
#define CONFIG_NVMEM_LAYOUTS 1
#define CONFIG_SCSI_MOD 1
#define CONFIG_IIO 1
#define CONFIG_I2C_HELPER_AUTO 1
#define CONFIG_HZ 100
#define CONFIG_RUNTIME_TESTING_MENU 1
#define CONFIG_EDAC_LEGACY_SYSFS 1
#define CONFIG_DVB_MT312_MODULE 1
#define CONFIG_IPV6_SIT 1
#define CONFIG_DVB_CX24110_MODULE 1
#define CONFIG_BLK_DEV_RAM_COUNT 16
#define CONFIG_MFD_VEXPRESS_SYSREG 1
#define CONFIG_DVB_TDA10086_MODULE 1
#define CONFIG_POWER_RESET_VEXPRESS 1
#define CONFIG_PREEMPTION 1
#define CONFIG_PL330_DMA 1
#define CONFIG_MFD_CORE 1
#define CONFIG_TRACE_IRQFLAGS_SUPPORT 1
#define CONFIG_AS_VFP_VMRS_FPINST 1
#define CONFIG_TIMERFD 1
#define CONFIG_RTC_HCTOSYS_DEVICE "rtc0"
#define CONFIG_SND_JACK_INPUT_DEV 1
#define CONFIG_JFFS2_FS 1
#define CONFIG_NET_VENDOR_MYRI 1
#define CONFIG_NET_VENDOR_META 1
#define CONFIG_IKCONFIG_PROC 1
#define CONFIG_GENERIC_IRQ_MULTI_HANDLER 1
#define CONFIG_DRM_GEM_DMA_HELPER 1
#define CONFIG_IRQ_DOMAIN 1
#define CONFIG_ARM_TIMER_SP804 1
#define CONFIG_HAVE_KERNEL_GZIP 1
#define CONFIG_LDISC_AUTOLOAD 1
#define CONFIG_CRYPTO_AKCIPHER2 1
#define CONFIG_WATCHDOG_HANDLE_BOOT_ENABLED 1
#define CONFIG_DEBUG_ALIGN_RODATA 1
#define CONFIG_CRYPTO_LIB_BLAKE2S_GENERIC 1
#define CONFIG_HAS_IOMEM 1
#define CONFIG_PCIEASPM 1
#define CONFIG_CMA_AREAS 8
#define CONFIG_MEDIA_TUNER_MXL5007T_MODULE 1
#define CONFIG_CLKSRC_MMIO 1
#define CONFIG_MEDIA_TUNER_FC0011_MODULE 1
#define CONFIG_USB_CHIPIDEA_UDC 1
#define CONFIG_ZBOOT_ROM_TEXT 0x0
#define CONFIG_XZ_DEC_POWERPC 1
#define CONFIG_BPF 1
#define CONFIG_XZ_DEC_ARM64 1
#define CONFIG_LOCALVERSION "-xilinx"
#define CONFIG_MOUSE_PS2_SYNAPTICS 1
#define CONFIG_IOSCHED_BFQ 1
#define CONFIG_DVB_RTL2830_MODULE 1
#define CONFIG_REGMAP_MMIO 1
#define CONFIG_IP_PNP_RARP 1
#define CONFIG_SLUB 1
#define CONFIG_STACKPROTECTOR 1
#define CONFIG_NET_VENDOR_AMD 1
#define CONFIG_MOUSE_PS2_ALPS 1
#define CONFIG_HAVE_REGS_AND_STACK_ACCESS_API 1
#define CONFIG_DVB_ZL10353_MODULE 1
#define CONFIG_DVB_TDA8083_MODULE 1
#define CONFIG_DVB_STV090x_MODULE 1
#define CONFIG_DVB_ASCOT2E_MODULE 1
#define CONFIG_MEDIA_TUNER_TEA5767_MODULE 1
#define CONFIG_SND_PROC_FS 1
#define CONFIG_HAVE_IRQ_TIME_ACCOUNTING 1
#define CONFIG_DVB_M88DS3103_MODULE 1
#define CONFIG_DVB_AF9013_MODULE 1
#define CONFIG_VHOST_MENU 1
#define CONFIG_LOG_CPU_MAX_BUF_SHIFT 12
#define CONFIG_PAGE_OFFSET 0xC0000000
#define CONFIG_SND_PCM 1
#define CONFIG_HAVE_KERNEL_LZO 1
#define CONFIG_OF_RESOLVE 1
#define CONFIG_VMSPLIT_3G 1
#define CONFIG_HOTPLUG_CORE_SYNC_DEAD 1
#define CONFIG_DVB_EC100_MODULE 1
#define CONFIG_EXPERT 1
#define CONFIG_DVB_DS3000_MODULE 1
#define CONFIG_USB_CHIPIDEA_TEGRA 1
#define CONFIG_UID16 1
#define CONFIG_SWAP 1
#define CONFIG_HAVE_STACKPROTECTOR 1
#define CONFIG_ARCH_HAS_DMA_ALLOC 1
#define CONFIG_HAVE_ARCH_JUMP_LABEL 1
#define CONFIG_DRM_XLNX 1
#define CONFIG_ARCH_HAS_NON_OVERLAPPING_ADDRESS_SPACE 1
#define CONFIG_MMC_SDHCI_PLTFM 1
#define CONFIG_OUTER_CACHE_SYNC 1
#define CONFIG_PREEMPT_RCU 1
#define CONFIG_HAVE_SYSCALL_TRACEPOINTS 1
#define CONFIG_LEDS_TRIGGER_BACKLIGHT 1
#define CONFIG_ARCH_SUPPORTS_KEXEC 1
#define CONFIG_HAVE_HW_BREAKPOINT 1
#define CONFIG_HAVE_NMI 1
#define CONFIG_DVB_RTL2832_SDR_MODULE 1
#define CONFIG_HAVE_VIRT_CPU_ACCOUNTING_GEN 1
#define CONFIG_GENERIC_CLOCKEVENTS_BROADCAST 1
#define CONFIG_RTC_NVMEM 1
#define CONFIG_ARM_VIRT_EXT 1
#define CONFIG_XARRAY_MULTI 1
#define CONFIG_MEDIA_TUNER_FC0013_MODULE 1
#define CONFIG_MDIO_DEVRES 1
#define CONFIG_XZ_DEC_ARM 1
#define CONFIG_DVB_RTL2832_MODULE 1
#define CONFIG_ARM_DMA_MEM_BUFFERABLE 1
#define CONFIG_ARM_UNWIND 1
#define CONFIG_NET_VENDOR_HUAWEI 1
#define CONFIG_CONFIGFS_FS 1
#define CONFIG_JFFS2_FS_WRITEBUFFER 1
#define CONFIG_DEFAULT_INIT ""
#define CONFIG_SND_SPI 1
#define CONFIG_HAVE_EXIT_THREAD 1
#define CONFIG_NET_VENDOR_AGERE 1
#define CONFIG_OF_RESERVED_MEM 1
#define CONFIG_HAVE_ARCH_PFN_VALID 1
#define CONFIG_REALTEK_PHY 1
#define CONFIG_CRYPTO_KPP2 1
#define CONFIG_BLK_DEV_LOOP_MIN_COUNT 8
#define CONFIG_MODVERSIONS 1
#define CONFIG_DCACHE_WORD_ACCESS 1
#define CONFIG_ARCH_SUPPORTS_CFI_CLANG 1
#define CONFIG_MEDIA_TUNER_TEA5761_MODULE 1
#define CONFIG_RUSTC_LLVM_VERSION 0
#define CONFIG_EXTCON 1
#define CONFIG_INPUT_KEYBOARD 1
#define CONFIG_GENERIC_IDLE_POLL_SETUP 1
#define CONFIG_MQ_IOSCHED_KYBER 1
#define CONFIG_XZ_DEC_RISCV 1
#define CONFIG_THREAD_INFO_IN_TASK 1
#define CONFIG_SYSFS 1
#define CONFIG_RD_ZSTD 1
#define CONFIG_NEON 1
#define CONFIG_HAVE_ARCH_THREAD_STRUCT_WHITELIST 1
#define CONFIG_MEDIA_TUNER_XC5000_MODULE 1
#define CONFIG_HAVE_RSEQ 1
#define CONFIG_DVB_CORE 1
#define CONFIG_HAVE_KCSAN_COMPILER 1
#define CONFIG_HIGHPTE 1
#define CONFIG_GCC10_NO_ARRAY_BOUNDS 1
#define CONFIG_MEDIA_TUNER_FC0012_MODULE 1
#define CONFIG_EEPROM_AT25 1
#define CONFIG_SPI_DYNAMIC 1
#define CONFIG_CPU_FREQ_GOV_ONDEMAND 1
#define CONFIG_GENERIC_CLOCKEVENTS 1
#define CONFIG_HAVE_SMP 1
#define CONFIG_RTC_CLASS 1
#define CONFIG_SND_SUPPORT_OLD_API 1
#define CONFIG_FWNODE_MDIO 1
#define CONFIG_PERF_EVENTS 1
#define CONFIG_NO_HZ_IDLE 1
#define CONFIG_USB_STORAGE 1
#define CONFIG_LOCKD_V4 1
#define CONFIG_WATCHDOG_CORE 1
#define CONFIG_ARCH_FLATMEM_ENABLE 1
#define CONFIG_MODULES_USE_ELF_REL 1
#define CONFIG_ARM_L1_CACHE_SHIFT 6
#define CONFIG_ARCH_HAS_SYNC_DMA_FOR_CPU 1
#define CONFIG_BQL 1
#define CONFIG_IO_URING 1
#define CONFIG_INPUT_MOUSE 1
#define CONFIG_DECOMPRESS_XZ 1
#define CONFIG_MTD_BLOCK 1
#define CONFIG_ETHERNET 1
#define CONFIG_MTD_CFI_I2 1
#define CONFIG_MIGHT_HAVE_CACHE_L2X0 1
#define CONFIG_TREE_SRCU 1
#define CONFIG_EEPROM_AT24 1
#define CONFIG_ARCH_HAS_STRICT_KERNEL_RWX 1
#define CONFIG_PREEMPT 1
#define CONFIG_CRC32_SLICEBY8 1
#define CONFIG_CRC16 1
#define CONFIG_PINCTRL_ZYNQ 1
#define CONFIG_USB_AUTOSUSPEND_DELAY 2
#define CONFIG_MUTEX_SPIN_ON_OWNER 1
#define CONFIG_FSNOTIFY 1
#define CONFIG_NET_FLOW_LIMIT 1
#define CONFIG_OF_OVERLAY 1
#define CONFIG_VIRTIO 1
#define CONFIG_MMC_BLOCK_MINORS 8
#define CONFIG_DVB_MT352_MODULE 1
#define CONFIG_ARM_CPU_SUSPEND 1
#define CONFIG_ARCH_MMAP_RND_BITS_MAX 16
#define CONFIG_MEDIA_TUNER_XC2028_MODULE 1
#define CONFIG_MEDIA_TUNER 1
#define CONFIG_SYNC_FILE 1
#define CONFIG_SND_PCI 1
#define CONFIG_IIO_KFIFO_BUF 1
#define CONFIG_MTD_CFI_I1 1
#define CONFIG_RD_LZMA 1
#define CONFIG_MEDIA_TUNER_MXL301RF_MODULE 1
#define CONFIG_ARCH_SUPPORTS_UPROBES 1
#define CONFIG_MEMORY_ISOLATION 1
#define CONFIG_HAVE_KRETPROBES 1
#define CONFIG_NET_VENDOR_EMULEX 1
#define CONFIG_DVB_OR51132_MODULE 1
#define CONFIG_CXD2880_SPI_DRV_MODULE 1
#define CONFIG_MACB_USE_HWSTAMP 1
#define CONFIG_V4L2_ASYNC 1
#define CONFIG_CADENCE_TTC_TIMER 1
#define CONFIG_IO_WQ 1
#define CONFIG_AS_VERSION 24200
#define CONFIG_USB_NET_DRIVERS 1
#define CONFIG_DVB_TUA6100_MODULE 1
#define CONFIG_NFS_FS 1
#define CONFIG_DVB_S5H1420_MODULE 1
#define CONFIG_FUTEX_PI 1
#define CONFIG_RTC_INTF_DEV 1
#define CONFIG_DVB_M88RS2000_MODULE 1
#define CONFIG_DVB_SI2165_MODULE 1
#define CONFIG_MTD_NAND_ECC_SW_HAMMING 1
#define CONFIG_ARCH_MMAP_RND_BITS 8
#define CONFIG_ARM_MODULE_PLTS 1
#define CONFIG_ARCH_DEFAULT_CRASH_DUMP 1
#define CONFIG_CPU_CACHE_VIPT 1
#define CONFIG_MEDIA_SDR_SUPPORT 1
#define CONFIG_NET_VENDOR_ALACRITECH 1
#define CONFIG_MEDIA_TUNER_IT913X_MODULE 1
#define CONFIG_NLS_DEFAULT "iso8859-1"
#define CONFIG_MEDIA_TUNER_XC4000_MODULE 1
#define CONFIG_SND_SOC_ADI_AXI_I2S 1
#define CONFIG_DMA_NEED_SYNC 1
#define CONFIG_REGULATOR 1
#define CONFIG_INPUT_SPARSEKMAP 1
#define CONFIG_DVB_LGDT3306A_MODULE 1
#define CONFIG_GRO_CELLS 1
#define CONFIG_GENERIC_STRNCPY_FROM_USER 1
#define CONFIG_PROC_EVENTS 1
#define CONFIG_LINEAR_RANGES 1
#define CONFIG_HID 1
#define CONFIG_NET_VENDOR_HISILICON 1
#define CONFIG_SND_SOC_GENERIC_DMAENGINE_PCM 1
#define CONFIG_CRYPTO_LIB_UTILS 1
#define CONFIG_SG_POOL 1
#define CONFIG_CC_HAS_WORKING_NOSANITIZE_ADDRESS 1
#define CONFIG_GENERIC_LIB_DEVMEM_IS_ALLOWED 1
#define CONFIG_RPMSG_CHAR_MODULE 1
#define CONFIG_DVB_STV6110x_MODULE 1
#define CONFIG_USB_PCI 1
#define CONFIG_SCHED_MM_CID 1
#define CONFIG_ADVISE_SYSCALLS 1
#define CONFIG_THERMAL_GOV_STEP_WISE 1
#define CONFIG_NET 1
#define CONFIG_MODULE_FORCE_UNLOAD 1
#define CONFIG_HAVE_OPTPROBES 1
#define CONFIG_WLAN_VENDOR_MICROCHIP 1
#define CONFIG_CPU_PM 1
#define CONFIG_USB_DEFAULT_AUTHORIZATION_MODE 1
#define CONFIG_NET_VENDOR_ENGLEDER 1
#define CONFIG_VIDEO_CAMERA_SENSOR 1
#define CONFIG_SCHED_SMT 1
#define CONFIG_UNINLINE_SPIN_UNLOCK 1
#define CONFIG_INITRAMFS_SOURCE ""
#define CONFIG_UNIX98_PTYS 1
#define CONFIG_CPU_PABRT_V7 1
#define CONFIG_DMA_DECLARE_COHERENT 1
#define CONFIG_USB_GADGET 1
#define CONFIG_EXECMEM 1
#define CONFIG_DVB_ZD1301_DEMOD_MODULE 1
#define CONFIG_NET_VENDOR_REALTEK 1
#define CONFIG_MEDIA_TUNER_TDA18212_MODULE 1
#define CONFIG_VT 1
#define CONFIG_SMP 1
#define CONFIG_FPGA_MGR_ZYNQ_FPGA 1
#define CONFIG_CLKSRC_ARM_GLOBAL_TIMER_SCHED_CLOCK 1
#define CONFIG_HAVE_ARCH_AUDITSYSCALL 1
#define CONFIG_BLK_DEV_LOOP 1
#define CONFIG_XILINX_INTC 1
#define CONFIG_RCU_STALL_COMMON 1
#define CONFIG_DVB_STB6100_MODULE 1
#define CONFIG_HAVE_PERF_EVENTS 1
#define CONFIG_CRYPTO_MANAGER_DISABLE_TESTS 1
#define CONFIG_USE_OF 1
#define CONFIG_MEDIA_TUNER_QT1010_MODULE 1
#define CONFIG_LTO_NONE 1
#define CONFIG_HAVE_DMA_CONTIGUOUS 1
#define CONFIG_DVB_ISL6405_MODULE 1
#define CONFIG_MTD_PHYSMAP 1
#define CONFIG_CAN_NETLINK 1
#define CONFIG_CRYPTO_MANAGER 1
#define CONFIG_SUSPEND_FREEZER 1
#define CONFIG_DVB_NET 1
#define CONFIG_DECOMPRESS_LZO 1
#define CONFIG_HAVE_ARCH_STACKLEAK 1
#define CONFIG_MEDIA_CAMERA_SUPPORT 1
#define CONFIG_LZ4_DECOMPRESS 1
#define CONFIG_ARM_ZYNQ_CPUIDLE 1
#define CONFIG_RD_LZO 1
#define CONFIG_NET_VENDOR_AQUANTIA 1
#define CONFIG_PINCTRL 1
#define CONFIG_STP_MODULE 1
#define CONFIG_DVB_VES1X93_MODULE 1
#define CONFIG_MEDIA_CONTROLLER 1
#define CONFIG_USB_SUPPORT 1
#define CONFIG_DVB_MXL5XX_MODULE 1
#define CONFIG_PREVENT_FIRMWARE_BUILD 1
#define CONFIG_CC_HAS_SANCOV_TRACE_PC 1
#define CONFIG_USB_ULPI 1
#define CONFIG_XILINX_AXI_EMAC 1
#define CONFIG_HW_PERF_EVENTS 1
#define CONFIG_XZ_DEC_ARMTHUMB 1
#define CONFIG_VIDEO_ADV7604 1
#define CONFIG_CPU_FREQ_DEFAULT_GOV_USERSPACE 1
#define CONFIG_CC_HAS_KASAN_GENERIC 1
#define CONFIG_ZLIB_INFLATE 1
#define CONFIG_BLK_DEV_RAM 1
#define CONFIG_VGA_ARB 1
#define CONFIG_SYS_SUPPORTS_APM_EMULATION 1
#define CONFIG_ARCH_USE_MEMTEST 1
#define CONFIG_HID_GENERIC 1
#define CONFIG_USB_PHY 1
#define CONFIG_VIDEO_XILINX_TPG 1
#define CONFIG_CAN_RAW 1
#define CONFIG_SPI_BITBANG 1
#define CONFIG_SWPHY 1
#define CONFIG_USB_CHIPIDEA_IMX 1
#define CONFIG_DRM_PANEL_BRIDGE 1
#define CONFIG_DIMLIB 1
#define CONFIG_ARM_PATCH_PHYS_VIRT 1
#define CONFIG_SPARSE_IRQ 1
#define CONFIG_DVB_TUNER_DIB0070_MODULE 1
#define CONFIG_SUSPEND 1
#define CONFIG_GRACE_PERIOD 1
#define CONFIG_CC_IMPLICIT_FALLTHROUGH "-Wimplicit-fallthrough=5"
#define CONFIG_WLAN_VENDOR_RALINK 1
#define CONFIG_RATIONAL 1
#define CONFIG_STACKPROTECTOR_PER_TASK 1
#define CONFIG_ARCH_WANT_GENERAL_HUGETLB 1
#define CONFIG_ARCH_MIGHT_HAVE_PC_PARPORT 1
#define CONFIG_RD_GZIP 1
#define CONFIG_CPU_V7 1
#define CONFIG_MSDOS_PARTITION 1
#define CONFIG_TIMER_PROBE 1
#define CONFIG_POWER_SUPPLY_HWMON 1
#define CONFIG_PHYLIB_LEDS 1
#define CONFIG_CPU_FREQ_GOV_CONSERVATIVE 1
#define CONFIG_ZSTD_COMMON 1
#define CONFIG_DEFAULT_SECURITY_DAC 1
#define CONFIG_WATCHDOG 1
#define CONFIG_NET_VENDOR_RDC 1
#define CONFIG_FIX_EARLYCON_MEM 1
#define CONFIG_DVB_A8293_MODULE 1
#define CONFIG_IRQCHIP 1
#define CONFIG_FW_LOADER 1
#define CONFIG_UIO_XILINX_APM 1
#define CONFIG_RTC_SYSTOHC 1
#define CONFIG_MEDIA_TUNER_MT20XX_MODULE 1
#define CONFIG_EXPORTFS 1
#define CONFIG_ALIGNMENT_TRAP 1
#define CONFIG_PANIC_TIMEOUT 0
#define CONFIG_EXT3_FS 1
#define CONFIG_PTP_1588_CLOCK 1
#define CONFIG_NET_CORE 1
#define CONFIG_DVB_LGDT330X_MODULE 1
#define CONFIG_LD_IS_BFD 1
#define CONFIG_MMU_LAZY_TLB_REFCOUNT 1
#define CONFIG_SND_PCM_ELD 1
#define CONFIG_DECOMPRESS_GZIP 1
#define CONFIG_HWMON 1
#define CONFIG_CLKSRC_VERSATILE 1
#define CONFIG_CPU_RMAP 1
#define CONFIG_BUFFER_HEAD 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_PATTERN 1
#define CONFIG_DMA_OF 1
#define CONFIG_DVB_SI2168_MODULE 1
#define CONFIG_SMP_ON_UP 1
#define CONFIG_NET_VENDOR_MELLANOX 1
#define CONFIG_NET_VENDOR_SAMSUNG 1
#define CONFIG_PCI_DOMAINS 1
#define CONFIG_IIO_TRIGGERED_BUFFER 1
#define CONFIG_EDAC_SYNOPSYS 1
#define CONFIG_SND_SOC_ADI_AXI_SPDIF 1
#define CONFIG_PROC_SYSCTL 1
#define CONFIG_MIGRATION 1
#define CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS 1
#define CONFIG_MTD_SPI_NOR_SWP_DISABLE_ON_VOLATILE 1
#define CONFIG_CURRENT_POINTER_IN_TPIDRURO 1
#define CONFIG_HAVE_HARDLOCKUP_DETECTOR_BUDDY 1
#define CONFIG_VIDEOBUF2_MEMOPS 1
#define CONFIG_USB_ZERO_MODULE 1
#define CONFIG_OF_MDIO 1
#define CONFIG_NVMEM_SYSFS 1
#define CONFIG_DVB_TDA18271C2DD_MODULE 1
#define CONFIG_SCSI_COMMON 1
#define CONFIG_RSEQ 1
#define CONFIG_NEW_LEDS 1
#define CONFIG_ARM_PMU 1
#define CONFIG_RAS 1
#define CONFIG_DVB_STV0367_MODULE 1
#define CONFIG_CC_HAVE_STACKPROTECTOR_TLS 1
#define CONFIG_KEYBOARD_GPIO_POLLED 1
#define CONFIG_MEDIA_TUNER_MT2060_MODULE 1
#define CONFIG_CC_HAS_ASM_INLINE 1
#define CONFIG_CC_HAS_ASM_GOTO_TIED_OUTPUT 1
#define CONFIG_BLK_DEV_INITRD 1
#define CONFIG_MEDIA_TUNER_TDA8290_MODULE 1
#define CONFIG_NEED_TASKS_RCU 1
#define CONFIG_INET 1
#define CONFIG_POWER_RESET 1
#define CONFIG_BLK_DEV_RAM_SIZE 16384
#define CONFIG_RPS 1
#define CONFIG_GENERIC_ARCH_TOPOLOGY 1
#define CONFIG_MEDIA_TUNER_MC44S803_MODULE 1
#define CONFIG_SND_DMAENGINE_PCM 1
#define CONFIG_EPOLL 1
#define CONFIG_CGROUPS 1
#define CONFIG_HAVE_ARCH_KASAN 1
#define CONFIG_CRC32 1
#define CONFIG_EXT4_FS 1
#define CONFIG_GPIO_CDEV 1
#define CONFIG_ARM_ERRATA_643719 1
#define CONFIG_USB_CHIPIDEA_PCI 1
#define CONFIG_SPI_ZYNQ_QSPI 1
#define CONFIG_DECOMPRESS_BZIP2 1
#define CONFIG_HAVE_ARCH_VMAP_STACK 1
#define CONFIG_RTC_LIB 1
#define CONFIG_PER_VMA_LOCK 1
#define CONFIG_DQL 1
#define CONFIG_SECCOMP_FILTER 1
#define CONFIG_TASKS_RCU 1
#define CONFIG_GCC_VERSION 130400
#define CONFIG_NET_VENDOR_RENESAS 1
#define CONFIG_GPIO_SYSFS 1
#define CONFIG_SYSCTL 1
#define CONFIG_PANIC_ON_OOPS_VALUE 0
#define CONFIG_NVMEM 1
#define CONFIG_CRYPTO_LIB_SHA1 1
#define CONFIG_SSB_POSSIBLE 1
#define CONFIG_NET_VENDOR_XILINX 1
#define CONFIG_WLAN_VENDOR_REALTEK 1
#define CONFIG_CPU_CP15 1
#define CONFIG_GPIO_GENERIC 1
#define CONFIG_PM_SLEEP_SMP 1
#define CONFIG_FIXED_PHY 1
#define CONFIG_CPU_32v6K 1
#define CONFIG_SERIAL_CORE_CONSOLE 1
#define CONFIG_NET_VENDOR_CISCO 1
#define CONFIG_XXHASH 1
#define CONFIG_DVB_DYNAMIC_MINORS 1
#define CONFIG_IRQ_DOMAIN_HIERARCHY 1
#define CONFIG_SPI_CADENCE 1
#define CONFIG_SND_JACK 1
#define CONFIG_CC_OPTIMIZE_FOR_SIZE 1
#define CONFIG_SLUB_CPU_PARTIAL 1
#define CONFIG_MTD_NAND_CORE 1
#define CONFIG_GENERIC_IRQ_PROBE 1
#define CONFIG_MOUSE_PS2_SMBUS 1
#define CONFIG_FRAME_WARN 1024
#define CONFIG_LD_VERSION 24200
#define CONFIG_VT_CONSOLE 1
#define CONFIG_I2C 1
#define CONFIG_SND_SOC 1
#define CONFIG_LEDS_CLASS 1
#define CONFIG_MEDIA_RADIO_SUPPORT 1
#define CONFIG_NET_VENDOR_ADI 1
#define CONFIG_PM_SLEEP 1
#define CONFIG_DRM_BRIDGE 1
#define CONFIG_IRQSTACKS 1
#define CONFIG_THERMAL_OF 1
#define CONFIG_NET_PTP_CLASSIFY 1
#define CONFIG_VMAP_STACK 1
#define CONFIG_GPIO_ZYNQ 1
#define CONFIG_PM 1
#define CONFIG_DST_CACHE 1
#define CONFIG_OLD_SIGACTION 1
#define CONFIG_ARM_CPU_TOPOLOGY 1
#define CONFIG_NET_VENDOR_GOOGLE 1
#define CONFIG_ARCH_SPARSEMEM_ENABLE 1
#define CONFIG_USB_EHCI_ROOT_HUB_TT 1
#define CONFIG_MARVELL_PHY 1
#define CONFIG_NLS 1
#define CONFIG_OID_REGISTRY 1
#define CONFIG_GENERIC_IRQ_MIGRATION 1
#define CONFIG_DVB_HORUS3A_MODULE 1
#define CONFIG_DVB_STV0297_MODULE 1
#define CONFIG_CC_NO_ARRAY_BOUNDS 1
#define CONFIG_CONTEXT_TRACKING_IDLE 1
#define CONFIG_JBD2 1
#define CONFIG_GENERIC_IRQ_EFFECTIVE_AFF_MASK 1
#define CONFIG_WIRELESS 1
#define CONFIG_ARM_ERRATA_754327 1
#define CONFIG_MEDIA_TUNER_MT2063_MODULE 1
#define CONFIG_DVB_STV6111_MODULE 1
#define CONFIG_REGMAP_SPI 1
#define CONFIG_DVB_CXD2841ER_MODULE 1
#define CONFIG_CRYPTO_SKCIPHER 1
#define CONFIG_FLATMEM 1
#define CONFIG_PCP_BATCH_SCALE_MAX 5
#define CONFIG_SERIO_LIBPS2 1
#define CONFIG_USB_DEFAULT_PERSIST 1
#define CONFIG_TCP_CONG_CUBIC 1
#define CONFIG_ARCH_HAS_UBSAN 1
#define CONFIG_DVB_DIB7000P_MODULE 1
#define CONFIG_JFFS2_SUMMARY 1
#define CONFIG_ARCH_WANT_DEFAULT_TOPDOWN_MMAP_LAYOUT 1
#define CONFIG_HAVE_SOFTIRQ_ON_OWN_STACK 1
#define CONFIG_MTD_CFI_AMDSTD 1
#define CONFIG_HAVE_CLK_PREPARE 1
#define CONFIG_USB_CONFIGFS_MASS_STORAGE 1
#define CONFIG_DEBUG_LL_INCLUDE "mach/debug-macro.S"
#define CONFIG_SUNRPC_GSS 1
#define CONFIG_EDAC_SUPPORT 1
#define CONFIG_SPI_MASTER 1
#define CONFIG_EFI_PARTITION 1
#define CONFIG_MTD_SPI_NOR 1
#define CONFIG_PCIE_BUS_DEFAULT 1
#define CONFIG_SND_SOC_ADI 1
#define CONFIG_FHANDLE 1
#define CONFIG_SGL_ALLOC 1
#define CONFIG_GENERIC_PCI_IOMAP 1
#define CONFIG_DVB_STV6110_MODULE 1
#define CONFIG_SOUND 1
#define CONFIG_LOCALVERSION_AUTO 1
#define CONFIG_GENERIC_ALLOCATOR 1
#define CONFIG_DVB_TDA1004X_MODULE 1
#define CONFIG_HAVE_ARCH_KGDB 1
#define CONFIG_MEDIA_TUNER_MSI001_MODULE 1
#define CONFIG_MTD_NAND_ECC 1
#define CONFIG_CRYPTO_AEAD2 1
#define CONFIG_ARCH_STACKWALK 1
#define CONFIG_SPI 1
#define CONFIG_DEBUG_INFO_NONE 1
#define CONFIG_HAVE_ARCH_MMAP_RND_BITS 1
#define CONFIG_HAVE_PERF_REGS 1
#define CONFIG_BL_SWITCHER 1
#define CONFIG_MTD_PHYSMAP_OF 1
#define CONFIG_DVB_STB0899_MODULE 1
#define CONFIG_PAGE_SIZE_LESS_THAN_256KB 1
#define CONFIG_HAS_IOPORT 1
#define CONFIG_STRICT_MODULE_RWX 1
#define CONFIG_PCI 1
#define CONFIG_SENSORS_PMBUS 1
#define CONFIG_CLANG_VERSION 0
#define CONFIG_DVB_HELENE_MODULE 1
#define CONFIG_ARCH_HAS_ELF_RANDOMIZE 1
#define CONFIG_SCSI 1
#define CONFIG_DVB_ZL10036_MODULE 1
#define CONFIG_INPUT_LEDS 1
#define CONFIG_USB_CHIPIDEA_GENERIC 1
#define CONFIG_GENERIC_CALIBRATE_DELAY 1
#define CONFIG_NET_VENDOR_SOLARFLARE 1
#define CONFIG_MEDIA_ANALOG_TV_SUPPORT 1
#define CONFIG_LD_ORPHAN_WARN_LEVEL "warn"
#define CONFIG_DVB_TDA10071_MODULE 1
#define CONFIG_MEDIA_TUNER_FC2580_MODULE 1
#define CONFIG_CC_HAS_ASM_GOTO_OUTPUT 1
#define CONFIG_DVB_IX2505V_MODULE 1
#define CONFIG_USB_OHCI_LITTLE_ENDIAN 1
#define CONFIG_DVB_VES1820_MODULE 1
#define CONFIG_DMA_OPS_HELPERS 1
#define CONFIG_DVB_STV0299_MODULE 1
#define CONFIG_USB_GADGET_STORAGE_NUM_BUFFERS 2
#define CONFIG_NET_VENDOR_TI 1
#define CONFIG_HAVE_ARCH_KFENCE 1
#define CONFIG_DECOMPRESS_ZSTD 1
#define CONFIG_MTD_MAP_BANK_WIDTH_4 1
#define CONFIG_OLD_SIGSUSPEND3 1
#define CONFIG_XPS 1
#define CONFIG_COMPAT_32BIT_TIME 1
#define CONFIG_HOTPLUG_CPU 1
#define CONFIG_WANT_DEV_COREDUMP 1
#define CONFIG_USB_LIBCOMPOSITE_MODULE 1
#define CONFIG_NET_VENDOR_PENSANDO 1
#define CONFIG_ARCH_HAS_SET_MEMORY 1
#define CONFIG_OF_CONFIGFS 1
#define CONFIG_DVB_CXD2880_MODULE 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_ZERO_BARE 1
#define CONFIG_KERNFS 1
#define CONFIG_SERIO_SERPORT 1
#define CONFIG_RD_XZ 1
#define CONFIG_HAVE_PAGE_SIZE_4KB 1
#define CONFIG_VIDEO_V4L2_I2C 1
#define CONFIG_UIO_PDRV_GENIRQ_MODULE 1
#define CONFIG_MSDOS_FS 1
#define CONFIG_USB_ULPI_BUS 1
#define CONFIG_VFP 1
#define CONFIG_DVB_S5H1411_MODULE 1
#define CONFIG_SENSORS_UCD9200 1
#define CONFIG_RPMSG_NS_MODULE 1
#define CONFIG_PROC_PAGE_MONITOR 1
#define CONFIG_HAVE_ARCH_SECCOMP_FILTER 1
#define CONFIG_EXT4_USE_FOR_EXT2 1
#define CONFIG_ARCH_SUSPEND_POSSIBLE 1
#define CONFIG_KPROBES 1
#define CONFIG_RT_MUTEXES 1
#define CONFIG_ROOT_NFS 1
#define CONFIG_RD_LZ4 1
#define CONFIG_DVB_MXL692_MODULE 1
#define CONFIG_DEFAULT_HOSTNAME "(none)"
#define CONFIG_GENERIC_NET_UTILS 1
#define CONFIG_PL310_ERRATA_727915 1
#define CONFIG_LEDS_TRIGGER_ONESHOT 1
#define CONFIG_SCSI_LOWLEVEL 1
#define CONFIG_RTC_DRV_PCF8563 1
#define CONFIG_NET_VENDOR_BROADCOM 1
#define CONFIG_RTC_SYSTOHC_DEVICE "rtc0"
#define CONFIG_RTC_INTF_PROC 1
#define CONFIG_USB_CHIPIDEA_NPCM 1
#define CONFIG_DVB_CX24123_MODULE 1
#define CONFIG_LD_CAN_USE_KEEP_IN_OVERLAY 1
#define CONFIG_USB_HID 1
#define CONFIG_CRYPTO_SKCIPHER2 1
#define CONFIG_MTD 1
#define CONFIG_PCI_MSI 1
#define CONFIG_WLAN_VENDOR_PURELIFI 1
#define CONFIG_MODULES_TREE_LOOKUP 1
#define CONFIG_CPU_SW_DOMAIN_PAN 1
#define CONFIG_MEDIA_TUNER_E4000_MODULE 1
#define CONFIG_CPU_FREQ_GOV_USERSPACE 1
#define CONFIG_HAVE_ARCH_BITREVERSE 1
#define CONFIG_DVB_S5H1409_MODULE 1
#define CONFIG_AUTO_ZRELADDR 1
#define CONFIG_ARCH_HAS_SETUP_DMA_OPS 1
#define CONFIG_MEDIA_TUNER_SIMPLE_MODULE 1
#define CONFIG_DUMMY_CONSOLE 1
#define CONFIG_DVB_TUNER_DIB0090_MODULE 1
#define CONFIG_HAVE_ARCH_TRACEHOOK 1
#define CONFIG_ARM_AMBA 1
#define CONFIG_SLUB_DEBUG 1
#define CONFIG_CPU_FREQ_THERMAL 1
#define CONFIG_DVB_CX24120_MODULE 1
#define CONFIG_CPU_THERMAL 1
#define CONFIG_HAVE_BUILDTIME_MCOUNT_SORT 1
#define CONFIG_VIDEOBUF2_V4L2 1
#define CONFIG_NET_VENDOR_ARC 1
#define CONFIG_NET_VENDOR_NVIDIA 1
#define CONFIG_UNIX 1
#define CONFIG_MEDIA_TUNER_M88RS6000T_MODULE 1
#define CONFIG_IRQ_WORK 1
#define CONFIG_NEED_SRCU_NMI_SAFE 1
#define CONFIG_DUMMY_CONSOLE_COLUMNS 80
#define CONFIG_STACKTRACE 1
#define CONFIG_PL310_ERRATA_769419 1
#define CONFIG_RCU_NEED_SEGCBLIST 1
#define CONFIG_CPU_32v7 1
#define CONFIG_NEED_DMA_MAP_STATE 1
#define CONFIG_SND_ARM 1
#define CONFIG_RCU_EXP_CPU_STALL_TIMEOUT 0
#define CONFIG_OF 1
#define CONFIG_ARCH_MMAP_RND_BITS_MIN 8
#define CONFIG_FPGA_MGR_ZYNQ_AFI_FPGA 1
#define CONFIG_NET_VENDOR_DEC 1
#define CONFIG_BLK_MQ_PCI 1
#define CONFIG_ARM_ERRATA_754322 1
#define CONFIG_SYSVIPC 1
#define CONFIG_LOCKDEP_SUPPORT 1
#define CONFIG_MEDIA_TUNER_TDA18250_MODULE 1
#define CONFIG_MEDIA_TUNER_QM1D1B0004_MODULE 1
#define CONFIG_NET_VENDOR_NETERION 1
#define CONFIG_USB_CONFIGFS_MODULE 1
#define CONFIG_CRYPTO 1
#define CONFIG_HAVE_ARCH_SECCOMP 1
#define CONFIG_DVB_TUNER_CX24113_MODULE 1
#define CONFIG_PROC_FS 1
#define CONFIG_SND_CTL_FAST_LOOKUP 1
#define CONFIG_NET_VENDOR_TEHUTI 1
#define CONFIG_MEDIA_PLATFORM_SUPPORT 1
#define CONFIG_POSIX_TIMERS 1
#define CONFIG_ARCH_HAS_CPU_FINALIZE_INIT 1
#define CONFIG_DVB_ISL6421_MODULE 1
#define CONFIG_RPMSG_VIRTIO_MODULE 1
#define CONFIG_NOP_USB_XCEIV 1
#define CONFIG_DVB_MAX_ADAPTERS 16
#define CONFIG_NET_VENDOR_SIS 1
#define CONFIG_DVB_DIB8000_MODULE 1
#define CONFIG_INET_DIAG 1
#define CONFIG_CLK_ICST 1
#define CONFIG_FS_IOMAP 1
#define CONFIG_INPUT_VIVALDIFMAP 1
#define CONFIG_ALLOW_DEV_COREDUMP 1
#define CONFIG_MMC_CQHCI 1
#define CONFIG_DEVTMPFS_MOUNT 1
#define CONFIG_HAVE_FTRACE_MCOUNT_RECORD 1
#define CONFIG_ARCH_HAS_DMA_OPS 1
#define CONFIG_CPU_SPECTRE 1
#define CONFIG_CONSOLE_LOGLEVEL_QUIET 4
#define CONFIG_NO_IOPORT_MAP 1
#define CONFIG_XILINX_PR_DECOUPLER 1
#define CONFIG_INET_TUNNEL 1
#define CONFIG_PCI_SYSCALL 1
#define CONFIG_LZO_DECOMPRESS 1
#define CONFIG_GENERIC_SMP_IDLE_THREAD 1
#define CONFIG_USB_ARCH_HAS_HCD 1
#define CONFIG_RTC_HCTOSYS 1
#define CONFIG_EXTRA_FIRMWARE ""
#define CONFIG_IP_MULTICAST 1
#define CONFIG_DVB_STV0288_MODULE 1
#define CONFIG_OF_KOBJ 1
#define CONFIG_ARM_GIC 1
#define CONFIG_MEDIA_TUNER_TUA9001_MODULE 1
#define CONFIG_USB_ULPI_VIEWPORT 1
#define CONFIG_DVB_CXD2099_MODULE 1
#define CONFIG_NET_VENDOR_LITEX 1
#define CONFIG_VIDEO_V4L2_SUBDEV_API 1
#define CONFIG_CPU_ISOLATION 1
#define CONFIG_NET_VENDOR_QLOGIC 1
#define CONFIG_GPIO_XILINX 1
#define CONFIG_SERIO 1
#define CONFIG_ARCH_SUPPORTS_ATOMIC_RMW 1
#define CONFIG_DVB_TDA826X_MODULE 1
#define CONFIG_LEGACY_TIOCSTI 1
#define CONFIG_FW_CACHE 1
#define CONFIG_ARCH_HAS_SYNC_DMA_FOR_DEVICE 1
#define CONFIG_REGMAP_I2C 1
#define CONFIG_MMC_SDHCI 1
#define CONFIG_PRINTK 1
#define CONFIG_PL353_SMC 1
#define CONFIG_UEVENT_HELPER_PATH ""
#define CONFIG_CC_VERSION_TEXT "gcc (GCC) 13.4.0"
#define CONFIG_BINFMT_ELF 1
#define CONFIG_HIGH_RES_TIMERS 1
#define CONFIG_MEMFD_CREATE 1
#define CONFIG_ATAGS 1
#define CONFIG_MTD_OF_PARTS 1
